@@ -1,4 +1,4 @@
-# (C) Copyright 2014 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from monascastatsd.metricbase import MetricBase
+from metricbase import MetricBase
 
 
 class Histogram(MetricBase):
